@@ -594,6 +594,7 @@ mod tests {
                 create_genesis_config, create_genesis_config_with_vote_accounts, GenesisConfigInfo,
                 ValidatorVoteKeypairs,
             },
+            vote_transaction::VoteTransaction,
         },
         solana_sdk::{
             account::ReadableAccount,
@@ -1315,7 +1316,7 @@ mod tests {
             hash: Hash::default(),
             timestamp: None,
         };
-        subscriptions.notify_vote(Pubkey::default(), &vote);
+        subscriptions.notify_vote(Pubkey::default(), VoteTransaction::from(vote));
 
         let response = receiver.recv();
         assert_eq!(
